@@ -14,6 +14,7 @@ Usage::
         CustomerGatewayAvailableWaiter,
         DescribeAddressesAttributePaginator,
         DescribeByoipCidrsPaginator,
+        DescribeCapacityReservationFleetsPaginator,
         DescribeCapacityReservationsPaginator,
         DescribeCarrierGatewaysPaginator,
         DescribeClassicLinkInstancesPaginator,
@@ -191,6 +192,7 @@ Usage::
 
     describe_addresses_attribute_paginator: DescribeAddressesAttributePaginator = client.get_paginator("describe_addresses_attribute")
     describe_byoip_cidrs_paginator: DescribeByoipCidrsPaginator = client.get_paginator("describe_byoip_cidrs")
+    describe_capacity_reservation_fleets_paginator: DescribeCapacityReservationFleetsPaginator = client.get_paginator("describe_capacity_reservation_fleets")
     describe_capacity_reservations_paginator: DescribeCapacityReservationsPaginator = client.get_paginator("describe_capacity_reservations")
     describe_carrier_gateways_paginator: DescribeCarrierGatewaysPaginator = client.get_paginator("describe_carrier_gateways")
     describe_classic_link_instances_paginator: DescribeClassicLinkInstancesPaginator = client.get_paginator("describe_classic_link_instances")
@@ -299,6 +301,7 @@ from .client import EC2Client
 from .paginator import (
     DescribeAddressesAttributePaginator,
     DescribeByoipCidrsPaginator,
+    DescribeCapacityReservationFleetsPaginator,
     DescribeCapacityReservationsPaginator,
     DescribeCarrierGatewaysPaginator,
     DescribeClassicLinkInstancesPaginator,
@@ -453,6 +456,7 @@ __all__ = (
     "CustomerGatewayAvailableWaiter",
     "DescribeAddressesAttributePaginator",
     "DescribeByoipCidrsPaginator",
+    "DescribeCapacityReservationFleetsPaginator",
     "DescribeCapacityReservationsPaginator",
     "DescribeCarrierGatewaysPaginator",
     "DescribeClassicLinkInstancesPaginator",
